# README #

This code is your shield, your [Aegis](https://en.wikipedia.org/wiki/Aegis), to carry with you into battle on the brave new web.


### Use the command line tools ###

* Use as a cloned repository: `virtualenv --python=``which python3`` virtualenv`
* `./virtualenv/bin/activate`
* `aegis debug`


### Use in aegis application ###

* `aegis create app_name`
* How to do something with your aegis app
* Updating
* Debugging

